@@ -5,6 +5,8 @@ KEDRO_SAGEMAKER_ARGS = f"{KEDRO_SAGEMAKER}_ARGS"
 KEDRO_SAGEMAKER_DEBUG = f"{KEDRO_SAGEMAKER}_DEBUG"
 KEDRO_SAGEMAKER_WORKING_DIRECTORY = f"{KEDRO_SAGEMAKER}_WD"
 KEDRO_SAGEMAKER_PARAMETERS = f"{KEDRO_SAGEMAKER}_PARAMETERS"
+KEDRO_SAGEMAKER_EXECUTION_ARN = f"{KEDRO_SAGEMAKER}_EXECUTION_ARN"
 KEDRO_SAGEMAKER_PARAM_KEY_PREFIX = f"{KEDRO_SAGEMAKER}_PARAM_KEY_"
 KEDRO_SAGEMAKER_PARAM_VALUE_PREFIX = f"{KEDRO_SAGEMAKER}_PARAM_VALUE_"
 KEDRO_SAGEMAKER_S3_TEMP_DIR_NAME = "kedro-sagemaker-tmp"
+MLFLOW_TAG_EXECUTION_ARN = "sagemaker_execution_arn"
